import { Injectable, BadRequestException } from '@nestjs/common';
import { BaseService } from '../base/base.service';
import { db, ObjectType, Prisma } from '@nice/common';
import EventBus, { CrudOperation } from '@server/utils/event-bus';

@Injectable()
export class BorrowRecordService extends BaseService<Prisma.BorrowRecordDelegate> {
  constructor() {
    super(db, ObjectType.BORROWRECORD, false);
  }

  async create(args: Prisma.BorrowRecordCreateArgs) {
    // 验证读者和图书是否属于同一个图书馆
    await this.validateLibraryMatch(
      args.data.readerId as string,
      args.data.bookId as string,
    );

    const result = await super.create(args);
    this.emitDataChanged(CrudOperation.CREATED, result);
    return result;
  }

  async update(args: Prisma.BorrowRecordUpdateArgs) {
    // 如果更新了读者或图书，需要验证
    if (args.data.readerId || args.data.bookId) {
      const record = await db.borrowRecord.findUnique({
        where: { id: args.where.id as string },
        select: { readerId: true, bookId: true },
      });

      const readerId = args.data.readerId
        ? typeof args.data.readerId === 'string'
          ? args.data.readerId
          : record.readerId
        : record.readerId;

      const bookId = args.data.bookId
        ? typeof args.data.bookId === 'string'
          ? args.data.bookId
          : record.bookId
        : record.bookId;

      await this.validateLibraryMatch(readerId, bookId);
    }

    const result = await super.update(args);
    this.emitDataChanged(CrudOperation.UPDATED, result);
    return result;
  }

  async findMany(args: Prisma.BorrowRecordFindManyArgs) {
    const result = await super.findMany(args);
    return result;
  }

  async findFirst(args: Prisma.BorrowRecordFindFirstArgs) {
    const result = await super.findFirst(args);
    return result;
  }

  async softDeleteByIds(ids: string[]) {
    const result = await super.softDeleteByIds(ids);
    this.emitDataChanged(CrudOperation.DELETED, result);
    return result;
  }

  private emitDataChanged(operation: CrudOperation, data: any) {
    EventBus.emit('dataChanged', {
      type: ObjectType.BORROWRECORD,
      operation,
      data,
    });
  }

  // 验证读者和图书是否属于同一个图书馆
  private async validateLibraryMatch(readerId: string, bookId: string) {
    const reader = await db.reader.findUnique({
      where: { id: readerId },
      select: { libraryId: true },
    });

    const book = await db.book.findUnique({
      where: { id: bookId },
      select: { libraryId: true },
    });

    if (!reader || !book) {
      throw new BadRequestException('读者或图书不存在');
    }

    if (reader.libraryId !== book.libraryId) {
      throw new BadRequestException('读者只能借阅所属图书馆的书籍');
    }
  }
}
