import { api } from '@nice/client';
import { message, Form, Modal } from 'antd';
import React, { useState, useEffect } from 'react';
import { SearchBar } from './components/SearchBar';
import { BookTable } from './components/BookTable';
import { BookModal } from './components/BookModal';
import { Book, Library } from './components/types';

export const BookPage = () => {
  const [modalOpen, setModalOpen] = useState(false);
  const [editingBook, setEditingBook] = useState<Book | undefined>();
  const [searchText, setSearchText] = useState('');
  const [form] = Form.useForm();
  // 查询数据
  const { data, isLoading, refetch, isError, error } = api.book.findMany.useQuery({
    where: {
      deletedAt: null,
      OR: searchText ? [
        { bookName: { contains: searchText } },
        { isbn: { contains: searchText } },
        { author: { contains: searchText } },
        { library: { name: { contains: searchText } } },
        { terms: { some:{ name: { contains: searchText } } }},
      ] : undefined
    },
    include: {
      library: true,
      terms:true,
    },
  });

  // 独立查询所有图书馆数据
  const { data: libraryList, isLoading: librarysLoading } = api.library.findMany.useQuery({
    where: {
      deletedAt: null,
    },
  });
  if (isError && error) {
    message.error('获取数据失败：' + error.message);
  }

  // 创建数据
  const createMutation = api.book.create.useMutation({
    onSuccess: () => {
      message.success('创建成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('创建失败：' + error.message);
    }
  });

  // 更新数据
  const updateMutation = api.book.update.useMutation({
    onSuccess: () => {
      message.success('更新成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('更新失败：' + error.message);
    }
  });

  // 删除数据
  const deleteMutation = api.book.softDeleteByIds.useMutation({
    onSuccess: () => {
      message.success('删除成功');
      refetch();
    },
    onError: (error) => {
      message.error('删除失败：' + error.message);
    }
  });

  // 处理搜索
  const handleSearch = () => {
    refetch();
  };

  // 处理添加
  const handleAdd = () => {
    setEditingBook(undefined);
    setModalOpen(true);
  };

  // 处理表单提交
  const handleModalOk = (values: any) => {
    if (editingBook) {
      updateMutation.mutate({
        where: { id: editingBook.id },
        data: {
          bookName: values.bookName,
          isbn: values.isbn,
          author: values.author,
          libraryId: values.libraryId,
          // 更新terms关联
          terms: values.termIds ? {
            set: values.termIds.map((id: string) => ({ id }))
          } : undefined
        }
      });
    } else {
      createMutation.mutate({

        bookName: values.bookName,
        isbn: values.isbn,
        author: values.author, 
        libraryId: values.libraryId,
        // 更新terms关联
        terms: values.termIds ? {
          connect: values.termIds.map((id: string) => ({ id }))
        } : undefined

      });
    } console.log(values);

  };

  return (
    <div className="p-6">
      <SearchBar
        searchText={searchText}
        onSearchTextChange={setSearchText}
        onSearch={handleSearch}
        onAdd={handleAdd}
        onImportSuccess={refetch}
      />

      <BookTable
        data={(data || []) as Book[]}
        loading={isLoading}
        onEdit={(book) => {
          setEditingBook(book);
          setModalOpen(true);
        }}
        onDelete={(ids) => deleteMutation.mutate({ ids })}
      />

      <BookModal
        open={modalOpen}
        editingBook={editingBook}
        libraryList={(libraryList || []) as Library[]}  // 传递俱乐部列表
        loading={createMutation.isPending || updateMutation.isPending}
        onOk={handleModalOk}
        onCancel={() => setModalOpen(false)}
      />
    </div>
  );
};

export default BookPage;