import { Button, Upload, message } from 'antd';
import { UploadOutlined, DownloadOutlined } from '@ant-design/icons';
import React from 'react';
import { Club } from './types';
import * as XLSX from 'xlsx';
import { api } from '@nice/client';

interface ImportExportButtonsProps {
  onImportSuccess: () => void;
  data: Club[];
}

export const ImportExportButtons: React.FC<ImportExportButtonsProps> = ({
  onImportSuccess,
  data,
}) => {
  const createMutation = api.club.create.useMutation({
    onSuccess: () => {
      // 成功时不显示单条消息，让最终统计来显示
    },
    onError: (error) => {
      // 只有当不是名称重复错误时才显示错误信息
      if (!error.message.includes('Unique constraint failed')) {
        message.error('导入失败: ' + error.message);
      }
    }
  });

  // 添加恢复记录的 mutation
  const restoreMutation = api.club.update.useMutation({
    onSuccess: () => {
      // 静默成功，不显示消息
    },
    onError: (error) => {
      console.error('恢复记录失败:', error);
    }
  });

  const handleImport = async (file: File) => {
    try {
      const reader = new FileReader();
      reader.onload = async (e) => {
        const workbook = XLSX.read(e.target?.result, { type: 'binary' });
        const sheetName = workbook.SheetNames[0];
        const worksheet = workbook.Sheets[sheetName];
        const jsonData = XLSX.utils.sheet_to_json(worksheet);

        let successCount = 0;
        let restoredCount = 0;
        let errorCount = 0;

        // 转换数据格式，包含 id 字段
        const clubData = jsonData.map((row: any) => ({
          id: row['ID'] || undefined,
          name: row['名称'],
          description: row['描述'],
          parentId: row['上级俱乐部ID'] || null,
        }));

        // 批量处理
        for (const club of clubData) {
          try {
            await createMutation.mutateAsync(club);
            successCount++;
          } catch (error: any) {
            if (error.message.includes('Unique constraint failed')) {
              try {
                // 这里需要 club.id，假设 clubData 里有 id 字段，否则需要先查找 id
                if (!club.id) {
                  errorCount++;
                  console.error('恢复记录失败: 缺少唯一标识 id');
                  continue;
                }
                await restoreMutation.mutateAsync({
                  where: {
                    id: club.id,
                  },
                  data: {
                    deletedAt: null,
                    description: club.description,
                    parentId: club.parentId,
                  }
                });
                restoredCount++;
              } catch (restoreError) {
                errorCount++;
                console.error('恢复记录失败:', restoreError);
              }
            } else {
              errorCount++;
              console.error('创建记录失败:', error);
            }
          }
        }

        // 显示导入结果
        if (successCount > 0 || restoredCount > 0) {
          let successMessage = [];
          if (successCount > 0) {
            successMessage.push(`新增 ${successCount} 条`);
          }
          if (restoredCount > 0) {
            successMessage.push(`恢复 ${restoredCount} 条`);
          }
          message.success(`导入完成：${successMessage.join('，')}`);
          onImportSuccess();
        }
        if (errorCount > 0) {
          message.warning(`${errorCount} 条记录导入失败`);
        }
      };
      reader.readAsBinaryString(file);
    } catch (error) {
      message.error('文件读取失败');
    }
    return false;
  };

  const handleExport = () => {
    try {
      const exportData = data.map(club => ({
        '名称': club.name,
        '描述': club.description,
        '上级俱乐部': club.parent?.name || '',
        '上级俱乐部ID': club.parentId || '',
        '创建时间': new Date(club.createdAt).toLocaleString(),
        '更新时间': new Date(club.updatedAt).toLocaleString(),
      }));

      const worksheet = XLSX.utils.json_to_sheet(exportData);
      const workbook = XLSX.utils.book_new();
      XLSX.utils.book_append_sheet(workbook, worksheet, '俱乐部列表');
      
      XLSX.writeFile(workbook, `俱乐部列表_${new Date().toLocaleDateString()}.xlsx`);
      message.success('导出成功');
    } catch (error) {
      message.error('导出失败: ' + (error as Error).message);
    }
  };

  return (
    <div className="flex space-x-2">
      <Upload
        accept=".xlsx,.xls"
        showUploadList={false}
        beforeUpload={handleImport}
      >
        <Button icon={<UploadOutlined />}>导入</Button>
      </Upload>
      <Button
        icon={<DownloadOutlined />}
        onClick={handleExport}
      >
        导出
      </Button>
    </div>
  );
};