import { api } from '@nice/client';
import { message, Form } from 'antd';
import React, { useState } from 'react';
import { SearchBar } from './components/SearchBar';
import { BorrowRecordTable } from './components/BorrowRecordTable';
import { BorrowRecordModal } from './components/BorrowRecordModal';
import { BorrowRecord } from './components/types';

export const BorrowRecordPage = () => {
    const [modalOpen, setModalOpen] = useState(false);
    const [editingRecord, setEditingRecord] = useState<BorrowRecord | undefined>();
    const [searchText, setSearchText] = useState('');
    const [selectedLibraryId, setSelectedLibraryId] = useState<string>('');
    const [form] = Form.useForm();

    // 查询借阅记录数据
    const { data, isLoading, refetch, isError, error } = api.borrowRecord.findMany.useQuery({
        where: {
            deletedAt: null,
            libraryId: selectedLibraryId || undefined,
            OR: searchText ? [
                { book: { bookName: { contains: searchText } } },
                { book: { isbn: { contains: searchText } } },
                { reader: { name: { contains: searchText } } },
                { reader: { username: { contains: searchText } } },
            ] : undefined
        },
        include: {
            library: true,
            reader: true,
            book: true,
        },
    });

    if (isError && error) {
        message.error('获取数据失败：' + error.message);
    }

    // 创建借阅记录
    const createMutation = api.borrowRecord.create.useMutation({
        onSuccess: () => {
            message.success('创建成功');
            setModalOpen(false);
            refetch();
        },
        onError: (error) => {
            message.error('创建失败：' + error.message);
        }
    });

    // 更新借阅记录
    const updateMutation = api.borrowRecord.update.useMutation({
        onSuccess: () => {
            message.success('更新成功');
            setModalOpen(false);
            refetch();
        },
        onError: (error) => {
            message.error('更新失败：' + error.message);
        }
    });

    // 删除借阅记录
    const deleteMutation = api.borrowRecord.softDeleteByIds.useMutation({
        onSuccess: () => {
            message.success('删除成功');
            refetch();
        },
        onError: (error) => {
            message.error('删除失败：' + error.message);
        }
    });

    // 处理搜索
    const handleSearch = () => {
        refetch();
    };

    // 处理添加
    const handleAdd = () => {
        setEditingRecord(undefined);
        setModalOpen(true);
    };

    // 处理表单提交
    const handleModalOk = (values: any) => {
        if (editingRecord) {
            updateMutation.mutate({
                where: { id: editingRecord.id },
                data: {
                    giveTime: values.giveTime,
                    backTime: values.backTime,
                    isbackTime: values.isbackTime,
                    libraryId: values.libraryId,
                    readerId: values.readerId,
                    bookId: values.bookId,
                }
            });
        } else {
            createMutation.mutate({
                giveTime: values.giveTime,
                backTime: values.backTime,
                isbackTime: values.isbackTime,
                libraryId: values.libraryId,
                readerId: values.readerId,
                bookId: values.bookId,
            });
        }
    };

    return (
        <div className="p-6">
            <h1 className="text-2xl font-bold mb-6 text-center">图书借阅记录管理</h1>

            <SearchBar
                searchText={searchText}
                onSearchTextChange={setSearchText}
                onSearch={handleSearch}
                onAdd={handleAdd}
                libraryId={selectedLibraryId}
                onLibraryChange={setSelectedLibraryId}
            />

            <BorrowRecordTable
                data={(data || []) as BorrowRecord[]}
                loading={isLoading}
                onEdit={(record) => {
                    setEditingRecord(record);
                    setModalOpen(true);
                }}
                onDelete={(ids) => deleteMutation.mutate({ ids })}
            />

            <BorrowRecordModal
                open={modalOpen}
                editingRecord={editingRecord}
                loading={createMutation.isPending || updateMutation.isPending}
                onOk={handleModalOk}
                onCancel={() => setModalOpen(false)}
            />
        </div>
    );
};

export default BorrowRecordPage;