import { Modal, Form, DatePicker, Select, Alert } from 'antd';
import { BorrowRecord, Library, Reader, Book } from './types';
import React, { useState, useEffect } from 'react';
import { api } from '@nice/client';
import dayjs from 'dayjs';

interface BorrowRecordModalProps {
    open: boolean;
    loading?: boolean;
    editingRecord?: BorrowRecord;
    onOk: (values: any) => void;
    onCancel: () => void;
}

export const BorrowRecordModal: React.FC<BorrowRecordModalProps> = ({
    open,
    loading,
    editingRecord,
    onOk,
    onCancel,
}) => {
    const [form] = Form.useForm();
    const [selectedLibraryId, setSelectedLibraryId] = useState<string>('');
    const [selectedReaderId, setSelectedReaderId] = useState<string>('');

    // 查询所有图书馆
    const { data: libraryList } = api.library.findMany.useQuery({
        where: { deletedAt: null },
    });

    // 根据选择的图书馆筛选读者
    const { data: readerList } = api.reader.findMany.useQuery({
        where: {
            deletedAt: null,
            libraryId: selectedLibraryId || undefined
        },
        include: { library: true }
    }, {
        enabled: !!selectedLibraryId
    });

    // 根据选择的图书馆筛选图书
    const { data: bookList } = api.book.findMany.useQuery({
        where: {
            deletedAt: null,
            libraryId: selectedLibraryId || undefined
        },
        include: { library: true }
    }, {
        enabled: !!selectedLibraryId
    });

    // 初始化表单数据
    useEffect(() => {
        if (editingRecord && open) {
            setSelectedLibraryId(editingRecord.libraryId);
            setSelectedReaderId(editingRecord.readerId);

            form.setFieldsValue({
                ...editingRecord,
                giveTime: dayjs(editingRecord.giveTime),
                backTime: dayjs(editingRecord.backTime),
                isbackTime: editingRecord.isbackTime ? dayjs(editingRecord.isbackTime) : null,
            });
        } else if (!editingRecord && open) {
            form.resetFields();
            setSelectedLibraryId('');
            setSelectedReaderId('');
        }
    }, [editingRecord, open, form]);

    // 处理图书馆选择变化
    const handleLibraryChange = (value: string) => {
        setSelectedLibraryId(value);
        // 清空读者和图书的选择
        form.setFieldsValue({ readerId: undefined, bookId: undefined });
    };

    // 处理读者选择变化
    const handleReaderChange = (value: string) => {
        setSelectedReaderId(value);

        // 如果选择了读者，自动设置图书馆为读者所属图书馆
        if (value && readerList) {
            const reader = readerList.find(r => r.id === value);
            if (reader && reader.libraryId) {
                setSelectedLibraryId(reader.libraryId);
                form.setFieldsValue({ libraryId: reader.libraryId });
            }
        }
    };

    return (
        <Modal
            title={editingRecord ? '编辑借阅记录' : '新增借阅记录'}
            open={open}
            onOk={() => form.submit()}
            onCancel={onCancel}
            confirmLoading={loading}
            width={600}
        >
            <Form
                form={form}
                layout="vertical"
                onFinish={(values) => {
                    const formData = {
                        ...values,
                        giveTime: values.giveTime.toDate(),
                        backTime: values.backTime.toDate(),
                        isbackTime: values.isbackTime ? values.isbackTime.toDate() : new Date(0),
                    };
                    onOk(formData);
                }}
            >
                <Form.Item
                    name="libraryId"
                    label="图书馆"
                    rules={[{ required: true, message: '请选择图书馆' }]}
                >
                    <Select
                        placeholder="请选择图书馆"
                        onChange={handleLibraryChange}
                    >
                        {libraryList?.map(library => (
                            <Select.Option key={library.id} value={library.id}>
                                {library.name}
                            </Select.Option>
                        ))}
                    </Select>
                </Form.Item>

                <Form.Item
                    name="readerId"
                    label="借阅人"
                    rules={[{ required: true, message: '请选择借阅人' }]}
                >
                    <Select
                        placeholder="请选择借阅人"
                        onChange={handleReaderChange}
                        disabled={!selectedLibraryId}
                    >
                        {readerList?.map(reader => (
                            <Select.Option key={reader.id} value={reader.id}>
                                {reader.name} ({reader.username})
                            </Select.Option>
                        ))}
                    </Select>
                </Form.Item>

                {!selectedLibraryId && (
                    <Alert
                        message="请先选择图书馆"
                        type="info"
                        showIcon
                        style={{ marginBottom: 16 }}
                    />
                )}

                <Form.Item
                    name="bookId"
                    label="借阅图书"
                    rules={[{ required: true, message: '请选择借阅图书' }]}
                >
                    <Select
                        placeholder="请选择图书"
                        disabled={!selectedLibraryId}
                    >
                        {bookList?.map(book => (
                            <Select.Option key={book.id} value={book.id}>
                                {book.bookName} (ISBN: {book.isbn})
                            </Select.Option>
                        ))}
                    </Select>
                </Form.Item>

                <Form.Item
                    name="giveTime"
                    label="借出时间"
                    rules={[{ required: true, message: '请选择借出时间' }]}
                >
                    <DatePicker showTime style={{ width: '100%' }} />
                </Form.Item>

                <Form.Item
                    name="backTime"
                    label="应还时间"
                    rules={[{ required: true, message: '请选择应还时间' }]}
                >
                    <DatePicker showTime style={{ width: '100%' }} />
                </Form.Item>

                <Form.Item
                    name="isbackTime"
                    label="实际归还时间"
                >
                    <DatePicker showTime style={{ width: '100%' }} />
                </Form.Item>
            </Form>
        </Modal>
    );
};