import { api } from '@nice/client';
import { message, Card, Empty, Pagination } from 'antd';
import React, { useState } from 'react';
import { SearchBar } from './components/SearchBar';
import { CommentTable } from './components/CommentTable';
import { CommentModal } from './components/CommentModal';
import { Comment } from './components/types';

export const CommentPage = () => {
    const [modalOpen, setModalOpen] = useState(false);
    const [editingRecord, setEditingRecord] = useState<Comment | undefined>();
    const [searchText, setSearchText] = useState('');
    const [selectedLibraryId, setSelectedLibraryId] = useState<string>('');
    const [commentType, setCommentType] = useState<'all' | 'book' | 'library'>('all');
    const [currentPage, setCurrentPage] = useState(1);
    const [pageSize, setPageSize] = useState(10);

    // 构建查询条件
    const buildWhereClause = () => {
        const where: any = {
            deletedAt: null,
        };

        // 如果选择了图书馆
        if (selectedLibraryId) {
            if (commentType === 'book') {
                where.book = { libraryId: selectedLibraryId };
            } else if (commentType === 'library') {
                where.libraryId = selectedLibraryId;
            } else {
                where.OR = [
                    { libraryId: selectedLibraryId },
                    { book: { libraryId: selectedLibraryId } }
                ];
            }
        }

        // 根据评论类型筛选
        if (commentType === 'book' && !selectedLibraryId) {
            where.bookId = { not: null };
        } else if (commentType === 'library' && !selectedLibraryId) {
            where.libraryId = { not: null };
        }

        // 搜索文本
        if (searchText) {
            where.OR = [
                { content: { contains: searchText } },
                { reader: { name: { contains: searchText } } },
                { reader: { username: { contains: searchText } } },
                { book: { bookName: { contains: searchText } } },
                { library: { name: { contains: searchText } } }
            ];
        }

        return where;
    };

    // 查询评论数据
    const { data, isLoading, refetch, isError, error } = api.comment.findMany.useQuery({
        where: buildWhereClause(),
        include: {
            library: true,
            reader: true,
            book: {
                include: {
                    library: true
                }
            }
        },
        orderBy: {
            createdAt: 'desc'
        },
        skip: (currentPage - 1) * pageSize,
        take: pageSize,
    });

    if (isError && error) {
        message.error('获取数据失败：' + error.message);
    }

    // 创建评论
    const createMutation = api.comment.create.useMutation({
        onSuccess: () => {
            message.success('评论发布成功');
            setModalOpen(false);
            refetch();
        },
        onError: (error) => {
            message.error('评论发布失败：' + error.message);
        }
    });

    // 更新评论
    const updateMutation = api.comment.update.useMutation({
        onSuccess: () => {
            message.success('评论更新成功');
            setModalOpen(false);
            refetch();
        },
        onError: (error) => {
            message.error('评论更新失败：' + error.message);
        }
    });

    // 删除评论
    const deleteMutation = api.comment.softDeleteByIds.useMutation({
        onSuccess: () => {
            message.success('评论删除成功');
            refetch();
        },
        onError: (error) => {
            message.error('评论删除失败：' + error.message);
        }
    });

    // 处理搜索
    const handleSearch = () => {
        setCurrentPage(1);
        refetch();
    };

    // 处理添加
    const handleAdd = () => {
        setEditingRecord(undefined);
        setModalOpen(true);
    };

    // 处理表单提交
    const handleModalOk = (values: any) => {
        if (editingRecord) {
            updateMutation.mutate({
                where: { id: editingRecord.id },
                data: {
                    content: values.content,
                    libraryId: values.libraryId,
                    readerId: values.readerId,
                    bookId: values.bookId,
                }
            });
        } else {
            createMutation.mutate({
                content: values.content,
                libraryId: values.libraryId,
                readerId: values.readerId,
                bookId: values.bookId,
            });
        }
    };

    // 处理分页变化
    const handlePageChange = (page: number, size?: number) => {
        setCurrentPage(page);
        if (size) {
            setPageSize(size);
        }
    };

    // 获取数据总数的估计值，用于分页
    // 由于我们不能直接获取总数，这里使用当前页数据长度来估计
    // 如果当前页数据长度小于页大小，说明已经到达最后一页
    const estimatedTotal = data && data.length < pageSize
        ? (currentPage - 1) * pageSize + data.length
        : (currentPage * pageSize) + 1; // 如果当前页数据等于页大小，可能还有更多数据

    return (
        <div className="p-6">
            <Card className="mb-6">
                <h1 className="text-2xl font-bold mb-6 text-center">图书与图书馆评论管理</h1>
                <p className="text-center text-gray-500 mb-6">
                    读者可以对任何图书馆和图书发表评论，分享阅读体验和使用感受
                </p>

                <SearchBar
                    searchText={searchText}
                    onSearchTextChange={setSearchText}
                    onSearch={handleSearch}
                    onAdd={handleAdd}
                    libraryId={selectedLibraryId}
                    onLibraryChange={setSelectedLibraryId}
                    commentType={commentType}
                    onCommentTypeChange={setCommentType}
                />
            </Card>

            <Card>
                {data && data.length > 0 ? (
                    <>
                        <CommentTable
                            data={(data || []) as Comment[]}
                            loading={isLoading}
                            onEdit={(record) => {
                                setEditingRecord(record);
                                setModalOpen(true);
                            }}
                            onDelete={(ids) => deleteMutation.mutate({ ids })}
                        />
                        <div className="mt-4 flex justify-end">
                            <Pagination
                                current={currentPage}
                                pageSize={pageSize}
                                total={estimatedTotal}
                                onChange={handlePageChange}
                                showSizeChanger
                                showQuickJumper
                                showTotal={(total) => `第 ${currentPage} 页 / 共 ${Math.ceil(total / pageSize)} 页`}
                            />
                        </div>
                    </>
                ) : (
                    <Empty
                        description={isLoading ? "加载中..." : "暂无评论数据"}
                        className="py-12"
                    />
                )}
            </Card>

            <CommentModal
                open={modalOpen}
                editingRecord={editingRecord}
                loading={createMutation.isPending || updateMutation.isPending}
                onOk={handleModalOk}
                onCancel={() => setModalOpen(false)}
            />
        </div>
    );
};

export default CommentPage;