import { Button, Space, Table, Popconfirm,  Avatar, Rate, Tag } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { Comment } from './types';
import React from 'react';
import { UserOutlined, BookOutlined, HomeOutlined } from '@ant-design/icons';


interface CommentTableProps {
    data: Comment[];
    loading?: boolean;
    onEdit: (record: Comment) => void;
    onDelete: (ids: string[]) => void;
}

export const CommentTable: React.FC<CommentTableProps> = ({
    data,
    loading,
    onEdit,
    onDelete,
}) => {
    console.log(data);
    
    const columns: ColumnsType<Comment> = [
        {
            title: '评论内容',
            dataIndex: 'content',
            key: 'content',
            ellipsis:true,
            render: (content: string) => (
                <Space>
                    {content}
                </Space>
            ),
            width: '30%',
        },
        {
            title: '评论人',
            dataIndex: ['reader', 'name'],
            key: 'readerName',
            render: (name: string, record: Comment) => (
                <Space>
                    <Avatar icon={<UserOutlined />} />
                    <span>{name} ({record.reader?.username})</span>
                </Space>
            ),
        },
        {
            title: '评论对象',
            key: 'commentTarget',
            render: (_, record: Comment) => {
                if (record.bookId && record.book) {
                    return (
                        <Space>
                            <BookOutlined />
                            <span>
                                <Tag color="blue">{record.book.library?.name}</Tag>
                                {record.book.bookName} (ISBN: {record.book.isbn})
                            </span>
                        </Space>
                    );
                } else if (record.libraryId && record.library) {
                    return (
                        <Space>
                            <HomeOutlined />
                            <span>{record.library.name}</span>
                        </Space>
                    );
                }
                return '-';
            },
            width: '25%',
        },
        {
            title: '评论时间',
            dataIndex: 'createdAt',
            key: 'createdAt',
            render: (date: string) => new Date(date).toLocaleString('zh-CN'),
            sorter: (a, b) => new Date(a.createdAt).getTime() - new Date(b.createdAt).getTime(),
        },
        {
            title: '操作',
            key: 'action',
            render: (_, record) => (
                <Space size="middle">
                    <Button type="link" onClick={() => onEdit(record)}>
                        编辑
                    </Button>
                    <Popconfirm
                        title="确定要删除这条评论吗？"
                        onConfirm={() => onDelete([record.id])}
                    >
                        <Button type="link" danger>
                            删除
                        </Button>
                    </Popconfirm>
                </Space>
            ),
        },
    ];

    return (
        <Table
            columns={columns}
            dataSource={data}
            loading={loading}
            rowKey="id"
            pagination={{ pageSize: 10 }}
            expandable={{
                expandedRowRender: (record) => (
                    <div className="p-4 bg-gray-50">
                        {record.content}
                        <div className="text-gray-500 text-sm mt-2">
                            评论时间: {new Date(record.createdAt).toLocaleString('zh-CN')}
                        </div>
                    </div>
                ),
            }}
        />
    );
};