import { api } from '@nice/client';
import { message, Form, Modal, Table, Space } from 'antd';
import React, { useState, useEffect } from 'react';
import { SearchBar } from './components/SearchBar';
import { GameTable } from './components/GameTable';
import { GameModal } from './components/GameModal';
import { Game } from './components/types';

export const GamePage = () => {
  const [modalOpen, setModalOpen] = useState(false);
  const [editingGame, setEditingGame] = useState<Game | undefined>();
  const [searchText, setSearchText] = useState('');
  const [messageApi, contextHolder] = message.useMessage();
  const [form] = Form.useForm();
  // 查询数据
  const { data, isLoading, refetch, isError, error } = api.game.findMany.useQuery({
    where: {
      deletedAt: null,
    },
    include: {
      clubs: true,
      sorties: {
        include: {
          driver: {
            select: {
              id: true,
              name: true,
            },
          },
          car: {
            select: {
              id: true,
              name: true,
            },
          },
        },
      },
    },
  });

  // 独立查询所有俱乐部数据
  const { data: clubList, isLoading: clubsLoading } = api.club.findMany.useQuery({
    where: {
      deletedAt: null,
    },
  });
  if (isError && error) {
    messageApi.error('获取数据失败：' + error.message);
  }

  // 创建数据
  const createMutation = api.game.create.useMutation({
    onSuccess: () => {
      messageApi.success('创建成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      messageApi.error('创建失败：' + error.message);
    }
  });

  // 更新数据
  const updateMutation = api.game.update.useMutation({
    onSuccess: () => {
      messageApi.success('更新成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      messageApi.error('更新失败：' + error.message);
    }
  });

  // 删除数据
  const deleteMutation = api.driver.softDeleteByIds.useMutation({
    onSuccess: () => {
      messageApi.success('删除成功');
      refetch();
    },
    onError: (error) => {
      messageApi.error('删除失败：' + error.message);
    }
  });

  // 处理搜索
  const handleSearch = () => {
    refetch();
  };

  // 处理添加
  const handleAdd = () => {
    setEditingGame(undefined);
    setModalOpen(true);
  };

  // 处理表单提交
  const handleModalOk = (values: any) => {
    if (editingGame) {
      updateMutation.mutate({
        where: { id: editingGame.id },
        data: values,
      });
    } else {
      createMutation.mutate({
        data: values,
      });
    }
    console.log(values);
  };

  // 添加统计信息
  const expandedRowRender = (record: Game) => {
    const stats = {
      avgTime: record.sorties.reduce((acc, curr) => acc + curr.totalTime, 0) / record.sorties.length,
      maxScore: Math.max(...record.sorties.map(s => s.score)),
      totalSorties: record.sorties.length,
    };

    return (
      <div>
        <div style={{ marginBottom: 16 }}>
          <Space>
            <span>平均时间: {stats.avgTime.toFixed(2)}秒</span>
            <span>最高分: {stats.maxScore.toFixed(2)}</span>
            <span>总车次: {stats.totalSorties}</span>
          </Space>
        </div>
        <Table
          columns={sortieColumns}
          dataSource={record.sorties}
          pagination={false}
          rowKey="id"
        />
      </div>
    );
  };

  return (
    <>
      {contextHolder}
      <div className="p-6">
        <SearchBar
          searchText={searchText}
          onSearchTextChange={setSearchText}
          onSearch={handleSearch}
          onAdd={handleAdd}
          onImportSuccess={refetch}
          data={data || []}
        />

        <GameTable
          data={data || []}
          loading={isLoading}
          onEdit={(driver) => {
            setEditingGame(driver);
            setModalOpen(true);
          }}
          onDelete={(ids) => deleteMutation.mutate({ ids })}
        />

        <GameModal
          open={modalOpen}
          editingGame={editingGame}
          clubList={clubList || []}  // 传递俱乐部列表
          loading={createMutation.isLoading || updateMutation.isLoading}
          onOk={handleModalOk}
          onCancel={() => setModalOpen(false)}
        />
      </div>
    </>
  );
};

export default GamePage;