import { useState } from 'react';

import { LibraryTable } from './components/LibraryTable';
import { LibraryModal } from './components/LibraryModal';
import { SearchBar } from './components/SearchBar';
import { Library } from './components/types';
import { api } from '@nice/client';
import { message } from 'antd';
import { useAuth } from '@web/src/providers/auth-provider';

export const LibraryPage = () => {
  const [modalOpen, setModalOpen] = useState(false);
  const [editingLibrary, setEditingLibrary] = useState<Library | undefined>();
  const [searchText, setSearchText] = useState('');
  const { user } = useAuth();

  // 查询条件：管理员只能看到自己的图书馆
  const whereCondition = {
    deletedAt: null,
    OR: searchText.trim() ? [
      { name: { contains: searchText } },
      { address: { contains: searchText } },
      { description: { contains: searchText } },
    ] : undefined,
    ...(user?.role === 'LIB_ADMIN' ? { adminId: user.id } : {})
  };

  // 查询数据
  const { data, isLoading, refetch, isError, error } = api.library.findMany.useQuery({
    where: whereCondition,
    include: {
      admin: true,
      _count: {
        select: {
          readers: true,
          books: true,
          borrowRecords: true,
          comments: true
        }
      }
    },
  });

  if (isError && error) {
    message.error('获取数据失败：' + error.message);
  }

  // 创建数据
  const createMutation = api.library.create.useMutation({
    onSuccess: () => {
      message.success('创建成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('创建失败：' + error.message);
    }
  });

  // 更新数据
  const updateMutation = api.library.update.useMutation({
    onSuccess: () => {
      message.success('更新成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('更新失败：' + error.message);
    }
  });

  // 删除数据
  const deleteMutation = api.library.softDeleteByIds.useMutation({
    onSuccess: () => {
      message.success('删除成功');
      refetch();
    },
    onError: (error) => {
      message.error('删除失败：' + error.message);
    }
  });

  // 处理搜索
  const handleSearch = () => {
    refetch();
  };

  // 处理添加
  const handleAdd = () => {
    setEditingLibrary(undefined);
    setModalOpen(true);
  };

  // 处理模态框取消
  const handleCancelModal = () => {
    setModalOpen(false);
    setEditingLibrary(undefined);
  };

  // 处理表单提交
  const handleModalOk = (values: any) => {
    if (editingLibrary) {
      updateMutation.mutate({
        where: { id: editingLibrary.id },
        data: {
          name: values.name,
          address: values.address,
          description: values.description,
          adminId: values.adminId
        }
      });
    } else {
      createMutation.mutate({
        name: values.name,
        address: values.address,
        description: values.description,
        adminId: values.adminId
      });
    }
  };

  return (
    <div className="p-6">
      <SearchBar
        searchText={searchText}
        onSearchTextChange={setSearchText}
        onSearch={handleSearch}
        onAdd={handleAdd}
        onImportSuccess={refetch}
        data={data || []}
      />

      <LibraryTable
        data={data || []}
        loading={isLoading}
        onEdit={(library) => {
          setEditingLibrary(library);
          setModalOpen(true);
        }}
        onDelete={(ids) => deleteMutation.mutate({ ids })}
      />

      <LibraryModal
        open={modalOpen}
        editingLibrary={editingLibrary}
        loading={createMutation.isPending || updateMutation.isPending}
        onOk={handleModalOk}
        onCancel={handleCancelModal}
      />
    </div>
  );
};

export default LibraryPage;