import { Table, Space, Button, Popconfirm, Badge, Tooltip } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { Library } from './types';
import { BookOutlined, TeamOutlined, SwapOutlined, CommentOutlined } from '@ant-design/icons';

import React from 'react';
interface LibraryTableProps {
  data: any[]; // 使用 any 类型，因为包含了 _count 等额外数据
  loading?: boolean;
  onEdit: (record: Library) => void;
  onDelete: (ids: string[]) => void;
}

export const LibraryTable: React.FC<LibraryTableProps> = ({
  data,
  loading,
  onEdit,
  onDelete,
}) => {
  const columns: ColumnsType<any> = [
    {
      title: '图书馆名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '地址',
      dataIndex: 'address',
      key: 'address',
    },
    {
      title: '图书馆描述',
      dataIndex: 'description',
      key: 'description',
      ellipsis: true,
    },
    {
      title: '管理员',
      dataIndex: ['admin', 'name'],
      key: 'admin',
      render: (text, record) => text || '未分配',
    },
    {
      title: '统计信息',
      key: 'stats',
      render: (_, record) => (
        <Space>
          <Tooltip title="读者数量">
            <Badge count={record._count?.readers || 0} showZero>
              <TeamOutlined style={{ fontSize: '16px' }} />
            </Badge>
          </Tooltip>
          <Tooltip title="图书数量">
            <Badge count={record._count?.books || 0} showZero>
              <BookOutlined style={{ fontSize: '16px' }} />
            </Badge>
          </Tooltip>
          <Tooltip title="借阅记录">
            <Badge count={record._count?.borrowRecords || 0} showZero>
              <SwapOutlined style={{ fontSize: '16px' }} />
            </Badge>
          </Tooltip>
          <Tooltip title="评论">
            <Badge count={record._count?.comments || 0} showZero>
              <CommentOutlined style={{ fontSize: '16px' }} />
            </Badge>
          </Tooltip>
        </Space>
      ),
    },
    {
      title: '创建时间',
      dataIndex: 'createdAt',
      key: 'createdAt',
      render: (date: string) => new Date(date).toLocaleString('zh-CN'),
    },
    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <Space size="middle">
          <Button type="link" onClick={() => onEdit(record)}>
            编辑
          </Button>
          <Popconfirm
            title="确定要删除吗？"
            description="删除后相关的读者、图书、借阅记录和评论将无法访问此图书馆"
            onConfirm={() => onDelete([record.id])}
          >
            <Button type="link" danger>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <Table
      columns={columns}
      dataSource={data}
      loading={loading}
      rowKey="id"
      pagination={{
        showSizeChanger: true,
        showQuickJumper: true,
        showTotal: (total) => `共 ${total} 条记录`,
      }}
    />
  );
};