import { api } from '@nice/client';
import { message, Form, Modal } from 'antd';
import React, { useState, useEffect } from 'react';
import { SearchBar } from './components/SearchBar';
import { ReaderTable } from './components/ReaderTable';
import { ReaderModal } from './components/ReaderModal';
import { Reader } from './components/types';

export const ReaderPage = () => {
  const [modalOpen, setModalOpen] = useState(false);
  const [editingReader, setEditingReader] = useState<Reader | undefined>();
  const [searchText, setSearchText] = useState('');
  const [form] = Form.useForm();
  // 查询数据
  const { data, isLoading, refetch, isError, error } = api.reader.findMany.useQuery({
    where: {
      deletedAt: null,
      OR: searchText ? [
        { username: { contains: searchText } },
        { gender: { contains: searchText } },
        { age: !isNaN(Number(searchText)) ? Number(searchText) : undefined }, 
        { relax: { contains: searchText } },
        { library: { name: { contains: searchText } } }
      ] : undefined
    },
    include: {
      library: true,
      terms: {  // 添加分类信息
        where: { deletedAt: null },
        include: {
          taxonomy: true
        }
      }

    },
  });

    // 查询所有读者分类
    const { data: readerTypes } = api.reader.getReaderTypes.useQuery();

    // 分配读者分类
    const assignTypeMutation = api.reader.assignReaderType.useMutation({
      onSuccess: () => {
        message.success('分类分配成功');
        refetch();
      },
      onError: (error) => {
        message.error('分类分配失败：' + error.message);
      }
    });
  
    // 移除读者分类
    const removeTypeMutation = api.reader.removeReaderType.useMutation({
      onSuccess: () => {
        message.success('分类移除成功');
        refetch();
      },
      onError: (error) => {
        message.error('分类移除失败：' + error.message);
      }
    });
  
    if (isError && error) {
      message.error('获取数据失败：' + error.message);
    }

    // 处理分类变更
  const handleTypeChange = async (readerId: string, termId: string, checked: boolean) => {
    if (checked) {
      await assignTypeMutation.mutateAsync({ readerId, termId });
    } else {
      await removeTypeMutation.mutateAsync({ readerId, termId });
    }
  };

  // 独立查询所有俱乐部数据
  const { data: libraryList, isLoading: librarysLoading } = api.library.findMany.useQuery({
    where: {
      deletedAt: null,
    },
  });
  if (isError && error) {
    message.error('获取数据失败：' + error.message);
  }

  // 创建数据
  const createMutation = api.reader.create.useMutation({
    onSuccess: () => {
      message.success('创建成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('创建失败：' + error.message);
    }
  });

  // 更新数据
  const updateMutation = api.reader.update.useMutation({
    onSuccess: () => {
      message.success('更新成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('更新失败：' + error.message);
    }
  });

  // 删除数据
  const deleteMutation = api.reader.softDeleteByIds.useMutation({
    onSuccess: () => {
      message.success('删除成功');
      refetch();
    },
    onError: (error) => {
      message.error('删除失败：' + error.message);
    }
  });

  // 处理搜索
  const handleSearch = () => {
    refetch();
  };

  // 处理添加
  const handleAdd = () => {
    setEditingReader(undefined);
    setModalOpen(true);
  };

  // 处理表单提交
  const handleModalOk = (values: any) => {
    if (editingReader) {
      updateMutation.mutate({
        where: { id: editingReader.id },
        data: {
          name: values.name,
          password: values.password,
          username: values.username,
          gender: values.gender,
          age: Number(values.age), // 确保 age 是数字类型
          relax: values.relax || null,
          libraryId: values.libraryId,
          terms: values.terms ? {
            connect: values.terms.map((id: string) => ({ id }))
          } : undefined
        }
      });
    } else {
      createMutation.mutate({

        name: values.name,
        password: values.password,
        username: values.username,
        gender: values.gender,
        age: Number(values.age), // 确保 age 是数字类型
        relax: values.relax || null,
        libraryId: values.libraryId,
        terms: values.terms ? {
          connect: values.terms.map((id: string) => ({ id }))
        } : undefined

      });
    } console.log(values);

  };

  return (
    <div className="p-6">
      <SearchBar
        searchText={searchText}
        onSearchTextChange={setSearchText}
        onSearch={handleSearch}
        onAdd={handleAdd}
        onImportSuccess={refetch}
        data={data || []}
      />

      <ReaderTable
        data={data || []}
        loading={isLoading}
        readerTypes={readerTypes || []}
        onEdit={(reader) => {
          setEditingReader(reader);
          setModalOpen(true);
        }}
        onDelete={(ids) => deleteMutation.mutate({ ids })}
        onTypeChange={handleTypeChange}
      />

      <ReaderModal
        open={modalOpen}
        editingReader={editingReader}
        libraryList={libraryList || []}  // 传递俱乐部列表
        readerTypes={readerTypes || []}
        loading={createMutation.isLoading || updateMutation.isLoading}
        onOk={handleModalOk}
        onCancel={() => setModalOpen(false)}
      />
    </div>
  );
};

export default ReaderPage;