import { useState } from 'react';
import { UserTable } from '@web/src/app/main/user/components/UserTable';
import { UserModal } from '@web/src/app/main/user/components/UserModal';
import { SearchBar } from '@web/src/app/main/user/components/SearchBar';
import { User, Library } from '@web/src/app/main/user/components/types';
import { api } from '@nice/client';
import { message } from 'antd';
import { useAuth } from '@web/src/providers/auth-provider';
import { Character } from '@nice/common'; // 或者从正确的路径导入

export const UserPage = () => {
    const [modalOpen, setModalOpen] = useState(false);
    const [editingUser, setEditingUser] = useState<User | undefined>();
    const [searchText, setSearchText] = useState('');
    const [roleFilter, setRoleFilter] = useState<string | null>(null);
    const { user: currentUser } = useAuth();

    // 查询条件
    const whereCondition = {
        deletedAt: null,
        OR: searchText.trim() ? [
            { name: { contains: searchText } },
            { username: { contains: searchText } },
        ] : undefined,
        ...(roleFilter ? { role: { equals: roleFilter as Character } } : {}),
    };

    // 查询数据
    const { data, isLoading, refetch, isError, error } = api.user.findMany.useQuery({
        where: whereCondition,
        include: {
            reader: {
                include: {
                    library: true
                }
            },
            library: true
        },
    });

    if (isError && error) {
        message.error('获取数据失败：' + error.message);
    }

    // 查询图书馆列表
    const { data: libraryList } = api.library.findMany.useQuery({
        where: {
            deletedAt: null,
            ...(currentUser?.role === 'LIB_ADMIN' ? { adminId: currentUser.id } : {})
        }
    });

    // 创建数据
    const createMutation = api.user.create.useMutation({
        onSuccess: () => {
            message.success('创建成功');
            setModalOpen(false);
            refetch();
        },
        onError: (error) => {
            message.error('创建失败：' + error.message);
        }
    });

    // 更新数据
    const updateMutation = api.user.update.useMutation({
        onSuccess: () => {
            message.success('更新成功');
            setModalOpen(false);
            refetch();
        },
        onError: (error) => {
            message.error('更新失败：' + error.message);
        }
    });

    // 删除数据
    const deleteMutation = api.user.softDeleteByIds.useMutation({
        onSuccess: () => {
            message.success('删除成功');
            refetch();
        },
        onError: (error) => {
            message.error('删除失败：' + error.message);
        }
    });

    // 处理搜索
    const handleSearch = () => {
        refetch();
    };

    // 处理添加
    const handleAdd = () => {
        setEditingUser(undefined);
        setModalOpen(true);
    };

    // 处理模态框取消
    const handleCancelModal = () => {
        setModalOpen(false);
        setEditingUser(undefined);
    };

    // 处理表单提交
    const handleModalOk = (values: any) => {
        if (editingUser) {
            const updateData: any = {
                name: values.name,
                gender: values.gender,
                age: values.age,
                role: values.role,
                relax: values.relax,
            };

            // 如果提供了密码，则更新密码
            if (values.password) {
                updateData.password = values.password;
            }

            // 如果是图书馆管理员，更新关联的图书馆
            if (values.role === 'LIB_ADMIN') {
                updateData.library = {
                    connect: { id: values.libraryId }
                };
            }

            updateMutation.mutate({
                where: { id: editingUser.id },
                data: updateData
            });
        } else {
            const createData: any = {
                name: values.name,
                username: values.username,
                password: values.password,
                gender: values.gender,
                age: values.age,
                role: values.role,
                relax: values.relax
            };

            // 如果是图书馆管理员，关联到图书馆
            if (values.role === 'LIB_ADMIN' && values.libraryId) {
                createData.library = {
                    connect: { id: values.libraryId }
                };
            }

            createMutation.mutate(createData);
        }
    };

    return (
        <div className="p-6">
            <SearchBar
                searchText={searchText}
                roleFilter={roleFilter}
                onSearchTextChange={setSearchText}
                onRoleFilterChange={setRoleFilter}
                onSearch={handleSearch}
                onAdd={handleAdd}
                onImportSuccess={refetch}
            />

            <UserTable
                data={(data || []) as User[]}
                loading={isLoading}
                onEdit={(user) => {
                    setEditingUser(user);
                    setModalOpen(true);
                }}
                onDelete={(ids) => deleteMutation.mutate({ ids })}
            />

            <UserModal
                open={modalOpen}
                editingUser={editingUser}
                libraryList={(libraryList || []) as Library[]}
                loading={createMutation.isPending || updateMutation.isPending}
                onOk={handleModalOk}
                onCancel={handleCancelModal}
            />
        </div>
    );
};

export default UserPage;
