import { Modal, Form, Input, Select, InputNumber } from 'antd';
import { User, Library } from './types';
import React, { useEffect } from 'react';

interface UserModalProps {
    open: boolean;
    loading?: boolean;
    editingUser?: User;
    libraryList?: Library[];
    onOk: (values: any) => void;
    onCancel: () => void;
}

export const UserModal: React.FC<UserModalProps> = ({
    open,
    loading,
    editingUser,
    libraryList,
    onOk,
    onCancel,
}) => {
    const [form] = Form.useForm();

    // 当编辑的用户变化时，重置表单
    useEffect(() => {
        if (open) {
            form.resetFields();

            // 如果是编辑模式，设置初始值
            if (editingUser) {
                const formValues = {
                    ...editingUser,
                    // 不回显密码
                    password: undefined,
                };
                form.setFieldsValue(formValues);
            }
        }
    }, [open, editingUser, form]);

    // 角色选项
    const roleOptions = [
        { label: '系统管理员', value: 'ADMIN' },
        { label: '图书馆管理员', value: 'LIB_ADMIN' },
        { label: '读者', value: 'READER' }
    ];

    // 当角色变化时，重置相关字段
    const handleRoleChange = (value: string) => {
        if (value === 'LIB_ADMIN') {
            // 图书馆管理员需要选择图书馆
            form.setFieldsValue({ libraryId: undefined });
        } else {
            // 其他角色不需要选择图书馆
            form.setFieldsValue({ libraryId: undefined });
        }
    };

    return (
        <Modal
            title={editingUser ? '编辑用户' : '新增用户'}
            open={open}
            onOk={() => form.submit()}
            onCancel={onCancel}
            confirmLoading={loading}
        >
            <Form
                form={form}
                layout="vertical"
                onFinish={(values) => {
                    // 确保数据格式正确
                    const formData = {
                        ...values,
                        age: parseInt(values.age, 10),
                    };
                    onOk(formData);
                }}
            >
                <Form.Item
                    name="name"
                    label="姓名"
                    rules={[{ required: true, message: '请输入姓名' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="username"
                    label="用户名"
                    rules={[{ required: true, message: '请输入用户名' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="password"
                    label="密码"
                    rules={[
                        {
                            required: !editingUser,
                            message: '请输入密码'
                        }
                    ]}
                >
                    <Input.Password placeholder={editingUser ? '不修改请留空' : '请输入密码'} />
                </Form.Item>

                <Form.Item
                    name="gender"
                    label="性别"
                    rules={[{ required: true, message: '请输入性别' }]}
                >
                    <Select>
                        <Select.Option value="男">男</Select.Option>
                        <Select.Option value="女">女</Select.Option>
                        <Select.Option value="其他">其他</Select.Option>
                    </Select>
                </Form.Item>

                <Form.Item
                    name="age"
                    label="年龄"
                    rules={[{ required: true, message: '请输入年龄' }]}
                >
                    <InputNumber min={1} max={120} style={{ width: '100%' }} />
                </Form.Item>

                <Form.Item
                    name="relax"
                    label="联系方式"
                >
                    <Input.TextArea />
                </Form.Item>

                <Form.Item
                    name="role"
                    label="角色"
                    rules={[{ required: true, message: '请选择角色' }]}
                >
                    <Select options={roleOptions} onChange={handleRoleChange} />
                </Form.Item>

                {/* 仅当角色为图书馆管理员时显示图书馆选择 */}
                <Form.Item
                    noStyle
                    shouldUpdate={(prevValues, currentValues) => prevValues.role !== currentValues.role}
                >
                    {({ getFieldValue }) =>
                        getFieldValue('role') === 'LIB_ADMIN' ? (
                            <Form.Item
                                name="libraryId"
                                label="管理的图书馆"
                                rules={[{ required: true, message: '请选择管理的图书馆' }]}
                            >
                                <Select
                                    allowClear
                                    placeholder="请选择图书馆"
                                >
                                    {libraryList?.map(library => (
                                        <Select.Option key={library.id} value={library.id}>
                                            {library.name}
                                        </Select.Option>
                                    ))}
                                </Select>
                            </Form.Item>
                        ) : null
                    }
                </Form.Item>
            </Form>
        </Modal>
    );
};