import { Table, Space, Button, Popconfirm, Tag } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { User } from './types';

import React from 'react';
interface UserTableProps {
  data: User[];
  loading?: boolean;
  onEdit: (record: User) => void;
  onDelete: (ids: string[]) => void;
}

export const UserTable: React.FC<UserTableProps> = ({
  data,
  loading,
  onEdit,
  onDelete,
}) => {
  // 角色显示标签颜色映射
  const roleColors = {
    ADMIN: 'red',
    LIB_ADMIN: 'blue',
    READER: 'green'
  };

  // 角色名称映射
  const roleLabels = {
    ADMIN: '系统管理员',
    LIB_ADMIN: '图书馆管理员',
    READER: '读者'
  };

  const columns: ColumnsType<User> = [
    {
      title: '姓名',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '用户名',
      dataIndex: 'username',
      key: 'username',
    },
    {
      title: '性别',
      dataIndex: 'gender',
      key: 'gender',
    },
    {
      title: '年龄',
      dataIndex: 'age',
      key: 'age',
    },
    {
      title: '联系方式',
      dataIndex: 'relax',
      key: 'relax',
    },
    {
      title: '角色',
      dataIndex: 'role',
      key: 'role',
      render: (role: string) => (
        <Tag color={roleColors[role as keyof typeof roleColors]}>
          {roleLabels[role as keyof typeof roleLabels]}
        </Tag>
      ),
    },
    {
      title: '关联信息',
      key: 'relation',
      render: (_, record) => {
        if (record.role === 'LIB_ADMIN' && record.library) {
          return <span>管理图书馆: {record.library.name}</span>;
        } else if (record.role === 'READER' && record.reader) {
          return <span>读者ID: {record.reader.id}</span>;
        }
        return '-';
      }
    },
    {
      title: '创建时间',
      dataIndex: 'createdAt',
      key: 'createdAt',
      render: (date: string) => new Date(date).toLocaleString('zh-CN'),
    },
    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <Space size="middle">
          <Button type="link" onClick={() => onEdit(record)}>
            编辑
          </Button>
          <Popconfirm
            title="确定要删除吗？"
            onConfirm={() => onDelete([record.id])}
          >
            <Button type="link" danger>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <Table
      columns={columns}
      dataSource={data}
      loading={loading}
      rowKey="id"
    />
  );
};